@@ -41,3 +41,32 @@ def test_cell_address(calc):
     assert calc('Sheet4!test', 'Yet another sheet').value == 16
     assert calc('SUM(Sheet4!test2)', 'Yet another sheet').value == 34
     assert calc('SUM([0]Sheet4!test2)', 'Yet another sheet').value == 34
+
+
+def test_single_cell_cache():
+    # Cache disabled
+    source = ExcelMock()
+    calculator = get_calculator()
+
+    op1 = calculator('A3', 'Sheet 1', source)
+    op2 = calculator('A3', 'Sheet 1', source)
+
+    assert op1 is not op2
+
+    # Cache enabled
+    source.use_cache = True
+    op1 = calculator('A3', 'Sheet 1', source)
+    op2 = calculator('A3', 'Sheet 1', source)
+
+    assert op1 is op2
+
+    # New cache value for A3
+    source.clear_cache()
+    op2 = calculator('A3', 'Sheet 1', source)
+    assert op1 is not op2
+
+    # New cache value for A3
+    source.remove_cell_cache('Sheet 1', 3, 1)
+    op3 = calculator('A3', 'Sheet 1', source)
+    assert op2 is not op3
+
