@@ -195,9 +195,15 @@ def test_CONCATENATE(calc):
 
 def test_INDEX(calc):
     assert calc('INDEX(Sheet4!A1:A3,1)', 'Yet another sheet').value == 13  # A1
+    assert calc('INDEX(Sheet4!A1:B3,1,2)', 'Yet another sheet').value == 16  # B1
     assert calc('INDEX(Sheet4!A1:A3,3)', 'Yet another sheet').value == 4  # A3
     assert calc('INDEX(Sheet4!A2:A3,2)', 'Yet another sheet').value == 4  # A3
 
+    assert calc('INDEX(Sheet4!A:A,3)', 'Yet another sheet').value == 4  # A3
+    assert calc('INDEX(Sheet4!A:A,3,1)', 'Yet another sheet').value == 4  # A3
+    assert calc('INDEX(Sheet4!3:3,1,1)', 'Yet another sheet').value == 4  # A3
+    assert calc('INDEX(Sheet4!3:3,1,2)', 'Yet another sheet').value == 2  # B3
+
     with pytest.raises(BadReference):
         assert calc('INDEX(Sheet4!A1:A3,100,1)', 'Yet another sheet').value
 
@@ -222,6 +228,12 @@ def test_INDEX(calc):
     with pytest.raises(BadReference):
         assert calc('INDEX(Sheet4!A1:C3,1,0)', 'Yet another sheet').value
 
+    with pytest.raises(BadReference):
+        assert calc('INDEX(Sheet4!A:A,3,2)', 'Yet another sheet').value
+
+    with pytest.raises(BadReference):
+        assert calc('INDEX(Sheet4!1:1,2)', 'Yet another sheet').value
+
 
 def test_SUBSTITUTE(calc):
     assert calc('SUBSTITUTE("123123123","1","22")', 'Yet another sheet').value == "222322232223"
